==> xml-path-3.2.0-sources.jar: io/restassured/internal/path/xml/XMLAssertion.java <==
package io.restassured.internal.path.xml;

import groovy.util.slurpersupport.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class XMLAssertion
  extends java.lang.Object  implements
    io.restassured.internal.assertion.Assertion,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.String getKey() { return (java.lang.String)null;}
public  void setKey(java.lang.String value) { }
public  java.util.Map<java.lang.String, java.lang.Object> getParams() { return (java.util.Map)null;}
public  void setParams(java.util.Map<java.lang.String, java.lang.Object> value) { }
public  java.lang.Object getResult(java.lang.Object object, boolean shouldConvertToJavaObject, boolean rootEvaluation) { return null;}
public  java.lang.Object getResult(java.lang.Object object, java.lang.Object config) { return null;}
public  java.lang.Object getChildResultAsJavaObject(java.lang.Object object) { return null;}
public  boolean isPathFragment(java.lang.String fragment) { return false;}
public  java.lang.String description() { return (java.lang.String)null;}
}

==> xml-path-5.4.0-sources.jar: io/restassured/internal/path/xml/XMLAssertion.java <==
package io.restassured.internal.path.xml;

import groovy.xml.slurpersupport.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class XMLAssertion
  extends java.lang.Object  implements
    io.restassured.internal.common.assertion.Assertion,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.String getKey() { return (java.lang.String)null;}
public  void setKey(java.lang.String value) { }
public  java.util.Map<java.lang.String, java.lang.Object> getParams() { return (java.util.Map)null;}
public  void setParams(java.util.Map<java.lang.String, java.lang.Object> value) { }
public  java.lang.Object getResult(java.lang.Object object, boolean shouldConvertToJavaObject, boolean rootEvaluation) { return null;}
public  java.lang.Object getResult(java.lang.Object object, java.lang.Object config) { return null;}
public  java.lang.Object getChildResultAsJavaObject(java.lang.Object object) { return null;}
public  boolean isPathFragment(java.lang.String fragment) { return false;}
public  java.lang.String description() { return (java.lang.String)null;}
}
